/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.crop.nl;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import nl.cloudfarming.client.crop.Classification;
import nl.cloudfarming.client.crop.Crop;
import nl.cloudfarming.client.crop.CropListProvider;
import org.openide.util.lookup.ServiceProvider;

/**
 *
 * @author Timon Veenstra
 */
@ServiceProvider(service = CropListProvider.class)
public class NlCropListProvider implements CropListProvider {

    private static final Map<String, Crop> CROPS;

    private static void addCrop(NlCrop crop) {
        CROPS.put(crop.getName(), crop);
    }

    static {
        CROPS = new HashMap<String, Crop>();
        for (NlCrop crop : NlCrop.values()) {
            addCrop(crop);
        }
    }

    @Override
    public String getModuleName() {
        return "crop-nl";
    }

    @Override
    public Crop getCropForKey(String key) {
        return CROPS.get(key);
    }

    @Override
    public List<Crop> getCrops() {
        return (List<Crop>) CROPS.values();
    }

    @Override
    public List<Classification> getClassifications() {
        Classification[] classifications = NlClassification.values();
        return Arrays.asList(classifications);
    }
}
